==> mozc_1.11.1522.102.orig.tar.bz2: mozc-1.11.1522.102/base/init_test.cc <==
// Copyright 2010-2013, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#include <string.h>
#include "base/base.h"
#include "base/util.h"
#include "testing/base/public/gunit.h"

namespace mozc {
namespace {

int g_counter = 0;

REGISTER_MODULE_INITIALIZER(init_test, { g_counter = 1; });
REGISTER_MODULE_RELOADER(reload_test, { g_counter = 2; });
REGISTER_MODULE_SHUTDOWN_HANDLER(shutdown_test, { g_counter = 3; });
REGISTER_MODULE_FINALIZER(finalize_test, { g_counter = 4; });

TEST(InitTest, InitBasicTest) {
  RunInitializers();
  EXPECT_EQ(1, g_counter);

  RunReloaders();
  EXPECT_EQ(2, g_counter);

  RunShutdownHandlers();
  EXPECT_EQ(3, g_counter);

  RunFinalizers();
  EXPECT_EQ(4, g_counter);
}

}  // namespace
}  // namespace mozc

==> mozc_1.12.1599.102.orig.tar.bz2: mozc-1.12.1599.102/base/init_test.cc <==
// Copyright 2010-2013, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#include "base/init.h"

#include <string.h>
#include "base/util.h"
#include "testing/base/public/gunit.h"

namespace mozc {
namespace {

int g_counter = 0;

REGISTER_MODULE_INITIALIZER(init_test, { g_counter = 1; });
REGISTER_MODULE_RELOADER(reload_test, { g_counter = 2; });
REGISTER_MODULE_SHUTDOWN_HANDLER(shutdown_test, { g_counter = 3; });
REGISTER_MODULE_FINALIZER(finalize_test, { g_counter = 4; });

TEST(InitTest, InitBasicTest) {
  RunInitializers();
  EXPECT_EQ(1, g_counter);

  RunReloaders();
  EXPECT_EQ(2, g_counter);

  RunShutdownHandlers();
  EXPECT_EQ(3, g_counter);

  RunFinalizers();
  EXPECT_EQ(4, g_counter);
}


}  // namespace
}  // namespace mozc
